import os
import yaml
import logging.config
import logging
import sys


def setup_logging(default_path='conf/logging.yaml', default_level=logging.INFO, env_key='LOG_CFG'):
    """
    | **@author:** Prathyush SP
    | Logging Setup
    """
    path = default_path
    value = os.getenv(env_key, None)
    if value:
        path = value
    if os.path.exists(path):
        with open(path, 'rt') as f:
            try:
                config = yaml.safe_load(f.read())
                logging.config.dictConfig(config)
                # coloredlogs.install()
            except Exception as e:
                sys.stderr.write(e)
                sys.stderr.write('Error in Logging Configuration. Using default configs')
                logging.basicConfig(level=default_level)
                # coloredlogs.install(level=default_level)
    else:
        logging.basicConfig(level=default_level)
        sys.stderr.write('Failed to load configuration file. Using default configs')
